This function gives the Empirical Best Linear Unbiased Prediction (EBLUP) or Empirical Best (EB) predictor under normality based on a Fay-Herriot model.
eblupfh(
formula,
data,
vardir,
method = "REML",
maxiter = 100,
precision = 1e-04,
scale = FALSE,
print_result = TRUE
)The function returns a list with the following objects (df_res and fit):
df_res a data frame that contains the following columns:
y variable response
eblup estimated results for each area
random_effect random effect for each area
vardir variance sampling from the direct estimator for each area
mse Mean Square Error
rse Relative Standart Error (%)
fit a list containing the following objects:
estcoef a data frame with the estimated model coefficients in the first column (beta),
their asymptotic standard errors in the second column (std.error),
the t-statistics in the third column (tvalue) and the p-values of the significance of each coefficient
in last column (pvalue)
model_formula model formula applied
method type of fitting method applied (ML or REML)
random_effect_var estimated random effect variance
convergence logical value that indicates the Fisher-scoring algorithm has converged or not
n_iter number of iterations performed by the Fisher-scoring algorithm.
goodness vector containing several goodness-of-fit measures: loglikehood, AIC, and BIC
an object of class formula that contains a description of the model to be fitted. The variables included in the formula must be contained in the data.
a data frame or a data frame extension (e.g. a tibble).
vector or column names from data that contain variance sampling from the direct estimator for each area.
Fitting method can be chosen between 'ML' and 'REML'.
maximum number of iterations allowed in the Fisher-scoring algorithm. Default is 100 iterations.
convergence tolerance limit for the Fisher-scoring algorithm. Default value is 0.0001.
scaling auxiliary variable or not, default value is FALSE.
print coefficient or not, default value is TRUE.
The model has a form that is response ~ auxiliary variables. where numeric type response variables can contain NA. When the response variable contains NA it will be estimated with cluster information.
Rao, J. N., & Molina, I. (2015). Small area estimation. John Wiley & Sons.
library(saens)
m1 <- eblupfh(y ~ x1 + x2 + x3, data = na.omit(mys), vardir = "var")
m1 <- eblupfh(y ~ x1 + x2 + x3, data = na.omit(mys), vardir = ~var)
Run the code above in your browser using DataLab