Learn R Programming

saens (version 0.1.0)

summary.eblupres: Summarizing EBLUP Model Fits.

Description

`summary` method for class "eblupres".

Usage

# S3 method for eblupres
summary(object, ...)

Value

The function returns a data frame that contains the following columns:

* y variable response

* eblup estimated results for each area

* random_effect random effect for each area

* vardir variance sampling from the direct estimator for each area

* mse Mean Square Error

* cluster cluster information for each area

* rse Relative Standart Error (

Arguments

object

EBLUP model.

...

further arguments passed to or from other methods.

Examples

Run this code
library(saens)

model1 <- eblupfh_cluster(y ~ x1 + x2 + x3, data = mys, vardir = "var", cluster = "clust")
summary(model1)

Run the code above in your browser using DataLab