powered by
`summary` method for class "eblupres".
# S3 method for eblupres summary(object, ...)
The function returns a data frame that contains the following columns:
* y variable response
y
* eblup estimated results for each area
eblup
* random_effect random effect for each area
random_effect
* vardir variance sampling from the direct estimator for each area
vardir
* mse Mean Square Error
mse
* cluster cluster information for each area
cluster
* rse Relative Standart Error (
rse
EBLUP model.
further arguments passed to or from other methods.
library(saens) model1 <- eblupfh_cluster(y ~ x1 + x2 + x3, data = mys, vardir = "var", cluster = "clust") summary(model1)
Run the code above in your browser using DataLab